# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ncbi_datasets_util',
                'doc_host': 'https://$GIT_USER_NAME.github.io',
                'git_url': 'https://github.com/$GIT_USER_NAME/ncbi_datasets_util',
                'lib_path': 'ncbi_datasets_util'},
  'syms': { 'ncbi_datasets_util.core': { 'ncbi_datasets_util.core.get_config': ('core.html#get_config', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.get_samplesheet': ( 'core.html#get_samplesheet',
                                                                                      'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.set_env_variables': ( 'core.html#set_env_variables',
                                                                                        'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.show_project_env_vars': ( 'core.html#show_project_env_vars',
                                                                                            'ncbi_datasets_util/core.py')},
            'ncbi_datasets_util.hello_world': { 'ncbi_datasets_util.hello_world.cli': ( 'downloader.html#cli',
                                                                                        'ncbi_datasets_util/hello_world.py'),
                                                'ncbi_datasets_util.hello_world.hello_world': ( 'downloader.html#hello_world',
                                                                                                'ncbi_datasets_util/hello_world.py')},
            'ncbi_datasets_util.some_string': {}}}
